/*
 * Copyright 2012-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.spring.start.site.extension.dependency.springnative;

import io.spring.initializr.generator.buildsystem.gradle.GradleBuild;
import io.spring.initializr.generator.spring.build.BuildCustomizer;

/**
 * A {@link BuildCustomizer} that configures Spring Native for Gradle using the Kotlin
 * DSL.
 *
 * @author Stephane Nicoll
 */
class SpringNativeKotlinDslGradleBuildCustomizer extends SpringNativeGradleBuildCustomizer {

	private static final String BOOT_BUILD_IMAGE_TASK = "org.springframework.boot.gradle.tasks.bundling.BootBuildImage";

	@Override
	protected void customizeSpringBootPlugin(GradleBuild build) {
		build.tasks().customizeWithType(BOOT_BUILD_IMAGE_TASK, (task) -> {
			task.attribute("builder", "\"paketobuildpacks/builder:tiny\"");
			task.attribute("environment", String.format("mapOf(\"%s\" to \"%s\")", "BP_NATIVE_IMAGE", "true"));
		});
	}

}
